.. _supported_visualization:

FinOL Visualization
=============

The FinOL project provides a suite of visualization tools to facilitate
a comprehensive evaluation of data-driven OLPS research. Here are some
examples:

1. Dynamic Training/Validation Loss Visualization

   .. raw:: html

      <p align="center">

.. raw:: html

   </p>

2. Daily Cumulative Wealth Visualization

   .. raw:: html

      <p align="center">

3. Daily DrawDown

   .. raw:: html

      <p align="center">

4. Transaction Cost-Adjusted Cumulative Wealth

   .. raw:: html

      <p align="center">

5. Comprehensive Radar Chart

   .. raw:: html

      <p align="center">